@@ -1,7 +1,9 @@
 from typing import Any, Dict
 
+from pandas.core.series import Series
+
 from ..error.illegal_attr_checker import IllegalAttrChecker
-from ..query_runner.query_runner import QueryResult, QueryRunner
+from ..query_runner.query_runner import QueryRunner
 from .graph_object import Graph
 
 
@@ -10,17 +12,17 @@ class GraphExportRunner(IllegalAttrChecker):
         self._query_runner = query_runner
         self._namespace = namespace
 
-    def __call__(self, G: Graph, **config: Any) -> QueryResult:
+    def __call__(self, G: Graph, **config: Any) -> Series:
         return self._export_call(G, config)
 
-    def _export_call(self, G: Graph, config: Dict[str, Any]) -> QueryResult:
+    def _export_call(self, G: Graph, config: Dict[str, Any]) -> Series:
         query = f"CALL {self._namespace}($graph_name, $config)"
         params = {"graph_name": G.name(), "config": config}
 
-        return self._query_runner.run_query(query, params)
+        return self._query_runner.run_query(query, params).squeeze()  # type: ignore
 
     # TODO: Add an integration test for this call.
-    def csv(self, G: Graph, **config: Any) -> QueryResult:
+    def csv(self, G: Graph, **config: Any) -> Series:
         self._namespace += ".csv"
 
         return self._export_call(G, config)
