@@ -3,7 +3,6 @@ from .graph.graph_endpoints import GraphEndpoints
 from .model.model_endpoints import ModelEndpoints
 from .pipeline.pipeline_endpoints import PipelineEndpoints
 from .query_runner.query_runner import QueryRunner
-from .similarity.similarity_endpoints import SimilarityEndpoints
 from .system.system_endpoints import SystemEndpoints
 from .topological_lp.topological_lp_endpoints import TopologicalLPEndpoints
 from .utils.util_endpoints import UtilEndpoints
@@ -17,7 +16,6 @@ class IndirectEndpoints(
     SystemEndpoints,
     TopologicalLPEndpoints,
     UtilEndpoints,
-    SimilarityEndpoints,
 ):
     def __init__(self, query_runner: QueryRunner, namespace: str):
         super().__init__(query_runner, namespace)
