@@ -1,3 +1,7 @@
+from typing import Tuple
+
+from pandas.core.series import Series
+
 from ..error.illegal_attr_checker import IllegalAttrChecker
 from ..error.uncallable_namespace import UncallableNamespace
 from ..query_runner.query_runner import QueryRunner
@@ -9,11 +13,11 @@ class LPPipelineCreateRunner(UncallableNamespace, IllegalAttrChecker):
         self._query_runner = query_runner
         self._namespace = namespace
 
-    def create(self, name: str) -> LPTrainingPipeline:
+    def create(self, name: str) -> Tuple[LPTrainingPipeline, Series]:
         self._namespace += ".create"
 
         query = f"CALL {self._namespace}($name)"
         params = {"name": name}
-        self._query_runner.run_query(query, params)
+        result = self._query_runner.run_query(query, params).squeeze()
 
-        return LPTrainingPipeline(name, self._query_runner)
+        return LPTrainingPipeline(name, self._query_runner), result
