@@ -1,12 +1,12 @@
 from abc import ABC, abstractmethod
-from typing import Any, Dict, List
+from typing import Any, Dict
 
-QueryResult = List[Dict[str, Any]]
+from pandas.core.frame import DataFrame
 
 
 class QueryRunner(ABC):
     @abstractmethod
-    def run_query(self, query: str, params: Dict[str, Any] = {}) -> QueryResult:
+    def run_query(self, query: str, params: Dict[str, Any] = {}) -> DataFrame:
         pass
 
     @abstractmethod
