@@ -1,7 +1,9 @@
 from typing import Any, Dict, List
 
+from pandas.core.frame import DataFrame
+
 from ..error.client_only_endpoint import client_only_endpoint
-from ..query_runner.query_runner import QueryResult, QueryRunner
+from ..query_runner.query_runner import QueryRunner
 from .util_proc_runner import UtilProcRunner
 
 
@@ -15,9 +17,7 @@ class UtilEndpoints:
         return UtilProcRunner(self._query_runner, f"{self._namespace}.util")
 
     @client_only_endpoint("gds")
-    def find_node_id(
-        self, labels: List[str] = [], properties: Dict[str, Any] = {}
-    ) -> int:
+    def find_node_id(self, labels: List[str] = [], properties: Dict[str, Any] = {}) -> int:
         label_match = None
         if labels:
             label_match = " AND ".join([f"n:{label}" for label in labels])
@@ -43,23 +43,21 @@ class UtilEndpoints:
 
         node_match = self._query_runner.run_query(query)
         if len(node_match) != 1:
-            raise ValueError(
-                f"Filter did not match with exactly one node: {node_match}"
-            )
+            raise ValueError(f"Filter did not match with exactly one node: {node_match}")
 
-        return node_match[0]["id"]  # type: ignore
+        return node_match["id"][0].item()  # type: ignore
 
-    def version(self) -> QueryResult:
+    def version(self) -> str:
         namespace = self._namespace + ".version"
-        return self._query_runner.run_query(f"RETURN {namespace}() as version")
+        result = self._query_runner.run_query(f"RETURN {namespace}() as version").squeeze()
 
-    def list(self) -> QueryResult:
+        return result  # type: ignore
+
+    def list(self) -> DataFrame:
         namespace = self._namespace + ".list"
         return self._query_runner.run_query(f"CALL {namespace}()")
 
-    def oneHotEncoding(
-        self, available_values: List[Any], selected_values: List[Any]
-    ) -> List[int]:
+    def oneHotEncoding(self, available_values: List[Any], selected_values: List[Any]) -> List[int]:
         namespace = self._namespace + ".oneHotEncoding"
 
         query = f"RETURN {namespace}($available_values, $selected_values) AS embedding"
@@ -69,4 +67,4 @@ class UtilEndpoints:
         }
         result = self._query_runner.run_query(query, params)
 
-        return result[0]["embedding"]  # type: ignore
+        return result["embedding"].squeeze()  # type: ignore
